@@ -39,9 +39,6 @@ class AMIProtocol(asyncio.Protocol):
                 self.responses.pop(response.id)
 
         elif 'Event' in message:
-            if message['Event'].lower() == 'shutdown':
-                self.connection_lost(None)
-
             self.manager.dispatch(message)
 
     def send(self, action: AMIAction):
